# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/models/models.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.builds import builds_pb2 as qwak_dot_builds_dot_builds__pb2
from _qwak_proto.qwak.projects import jfrog_project_spec_pb2 as qwak_dot_projects_dot_jfrog__project__spec__pb2
from _qwak_proto.qwak.models import models_query_pb2 as qwak_dot_models_dot_models__query__pb2
from _qwak_proto.qwak.audience.v1 import audience_pb2 as qwak_dot_audience_dot_v1_dot_audience__pb2
from _qwak_proto.qwak.deployment import deployment_pb2 as qwak_dot_deployment_dot_deployment__pb2
from _qwak_proto.qwak.build.v1 import build_pb2 as qwak_dot_build_dot_v1_dot_build__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18qwak/models/models.proto\x12\x16qwak.models.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18qwak/builds/builds.proto\x1a&qwak/projects/jfrog_project_spec.proto\x1a\x1eqwak/models/models_query.proto\x1a\x1fqwak/audience/v1/audience.proto\x1a qwak/deployment/deployment.proto\x1a\x19qwak/build/v1/build.proto\"\x9b\x01\n\x12\x43reateModelRequest\x12\x35\n\nmodel_spec\x18\x01 \x01(\x0b\x32!.qwak.models.management.ModelSpec\x12N\n\x12jfrog_project_spec\x18\x02 \x01(\x0b\x32\x32.qwak.projects.management.ModelRepositoryJFrogSpec\"\'\n\x13\x43reateModelResponse\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\'\n\x11ListModelsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"C\n\x12ListModelsResponse\x12-\n\x06models\x18\x01 \x03(\x0b\x32\x1d.qwak.models.management.Model\"\xf0\x01\n\x1aListModelsPaginatedRequest\x12\x13\n\tpage_size\x18\x01 \x01(\x05H\x00\x12\x10\n\x06\x63ursor\x18\x02 \x01(\tH\x01\x12\x39\n\x0bsort_models\x18\x03 \x01(\x0b\x32\".qwak.models.management.SortModelsH\x02\x12\x30\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\x1e.qwak.models.management.FilterH\x03\x42\x0f\n\rpage_size_optB\x0c\n\ncursor_optB\x11\n\x0fsort_models_optB\x0c\n\nfilter_opt\"\x8a\x01\n\x1bListModelsPaginatedResponse\x12-\n\x06models\x18\x01 \x03(\x0b\x32\x1d.qwak.models.management.Model\x12<\n\x08metadata\x18\x02 \x01(\x0b\x32*.qwak.models.management.PaginationMetadata\"I\n\x0fGetModelRequest\x12\x12\n\x08model_id\x18\x01 \x01(\tH\x00\x12\x14\n\nmodel_uuid\x18\x02 \x01(\tH\x00\x42\x0c\n\nidentifier\"@\n\x10GetModelResponse\x12,\n\x05model\x18\x01 \x01(\x0b\x32\x1d.qwak.models.management.Model\"E\n\x1bListModelsByModelIdsRequest\x12\x11\n\tmodel_ids\x18\x01 \x03(\t\x12\x13\n\x0bmodel_uuids\x18\x02 \x03(\t\":\n\x12\x44\x65leteModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteModelResponse\"q\n\x12UpdateModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12I\n\x11model_spec_config\x18\x02 \x01(\x0b\x32..qwak.models.management.ModelSpecConfiguration\"L\n\x13UpdateModelResponse\x12\x35\n\nmodel_spec\x18\x01 \x01(\x0b\x32!.qwak.models.management.ModelSpec\"<\n\x13\x43reateBranchRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x02 \x01(\t\")\n\x14\x43reateBranchResponse\x12\x11\n\tbranch_id\x18\x01 \x01(\t\"(\n\x13\x44\x65leteBranchRequest\x12\x11\n\tbranch_id\x18\x01 \x01(\t\"\x16\n\x14\x44\x65leteBranchResponse\"N\n\x14IsModelExistsRequest\x12\x12\n\x08model_id\x18\x01 \x01(\tH\x00\x12\x14\n\nmodel_uuid\x18\x02 \x01(\tH\x00\x42\x0c\n\nidentifier\"\'\n\x15IsModelExistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\"\xda\x01\n\tModelSpec\x12\x16\n\x0emodel_named_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x14\n\nproject_id\x18\x03 \x01(\tH\x00\x12\x16\n\x0cproject_name\x18\x06 \x01(\tH\x00\x12\x19\n\x11model_description\x18\x04 \x01(\t\x12@\n\x10model_build_type\x18\x05 \x01(\x0b\x32&.qwak.models.management.ModelBuildTypeB\x14\n\x12project_identifier\"\xc7\x02\n\nModelBrief\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x19\n\x11model_description\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12N\n\x17\x64\x65ployment_model_status\x18\n \x01(\x0e\x32-.qwak.models.management.DeploymentModelStatus\"3\n\x16ModelSpecConfiguration\x12\x19\n\x11model_description\x18\x04 \x01(\t\"\xf4\x04\n\x05Model\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x05 \x01(\t\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x39\n\x0cmodel_status\x18\x07 \x01(\x0e\x32#.qwak.models.management.ModelStatus\x12\x19\n\x11model_description\x18\x08 \x01(\t\x12\x12\n\nproject_id\x18\t \x01(\t\x12\x30\n\x08\x62ranches\x18\n \x03(\x0b\x32\x1e.qwak.models.management.Branch\x12N\n\x17\x64\x65ployment_model_status\x18\x0b \x01(\x0e\x32-.qwak.models.management.DeploymentModelStatus\x12\x0c\n\x04uuid\x18\x0c \x01(\t\x12\x42\n\nmodel_type\x18\r \x01(\x0e\x32..qwak.deployment.management.KubeDeploymentType\x12\x14\n\x0cproject_name\x18\x0e \x01(\t\x12@\n\x10model_build_type\x18\x0f \x01(\x0b\x32&.qwak.models.management.ModelBuildType\x12\x19\n\x11jfrog_project_key\x18\x10 \x01(\t\"\x96\x01\n\x0eModelBuildType\x12\x30\n\x06source\x18\x01 \x01(\x0b\x32\x1e.qwak.models.management.SourceH\x00\x12J\n\x14model_registry_image\x18\x02 \x01(\x0b\x32*.qwak.models.management.ModelRegistryImageH\x00\x42\x06\n\x04type\"\x08\n\x06Source\"3\n\x12ModelRegistryImage\x12\x1d\n\x15last_image_identifier\x18\x01 \x01(\t\"\xeb\x01\n\x06\x42ranch\x12\x11\n\tbranch_id\x18\x01 \x01(\t\x12\x13\n\x0b\x62ranch_name\x18\x02 \x01(\t\x12\x42\n\rbranch_status\x18\x04 \x01(\x0e\x32+.qwak.models.management.Branch.BranchStatus\x12\x10\n\x08model_id\x18\x05 \x01(\t\x12\x1d\n\x11\x64\x65ployed_build_id\x18\x06 \x01(\tB\x02\x18\x01\"D\n\x0c\x42ranchStatus\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\r\n\tSUSPENDED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x01\"B\n\x1bGetDeploymentDetailsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x11\n\tbranch_id\x18\x02 \x01(\t\"e\n\x1cGetDeploymentDetailsResponse\x12\x45\n\x12\x64\x65ployment_details\x18\x01 \x01(\x0b\x32).qwak.models.management.DeploymentDetails\"\x93\x02\n\x11\x44\x65ploymentDetails\x12\x31\n\rlast_deployed\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x16\n\x0enumber_of_pods\x18\x03 \x01(\x05\x12\x14\n\x0c\x63pu_fraction\x18\x04 \x01(\x02\x12\x15\n\rmemory_amount\x18\x05 \x01(\x05\x12\x38\n\x0cmemory_units\x18\x06 \x01(\x0e\x32\".qwak.models.management.MemoryUnit\x12\x19\n\x11number_of_workers\x18\x07 \x01(\x05\x12\x1f\n\x17http_request_timeout_ms\x18\x08 \x01(\x05\"/\n\x19ListModelsMetadataRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"[\n\x1aListModelsMetadataResponse\x12=\n\x0emodel_metadata\x18\x01 \x03(\x0b\x32%.qwak.models.management.ModelMetadata\"+\n\x17GetModelMetadataRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"Y\n\x18GetModelMetadataResponse\x12=\n\x0emodel_metadata\x18\x01 \x01(\x0b\x32%.qwak.models.management.ModelMetadata\"h\n\x11\x45nvironmentRoutes\x12\x13\n\x0b\x65nvironment\x18\x01 \x01(\t\x12>\n\x0f\x61udience_routes\x18\x02 \x03(\x0b\x32%.qwak.audience.v1.AudienceRoutesEntry\"\xb8\x05\n\rModelMetadata\x12,\n\x05model\x18\x01 \x01(\x0b\x32\x1d.qwak.models.management.Model\x12I\n\x12\x64\x65ployment_details\x18\x02 \x03(\x0b\x32-.qwak.deployment.management.DeploymentDetails\x12r\n\x1e\x61udience_routes_by_environment\x18\x03 \x03(\x0b\x32\x46.qwak.models.management.ModelMetadata.AudienceRoutesByEnvironmentEntryB\x02\x18\x01\x12\x30\n\x05\x62uild\x18\x04 \x03(\x0b\x32\x1d.qwak.builds.management.BuildB\x02\x18\x01\x12}\n&audience_routes_grouped_by_environment\x18\x05 \x03(\x0b\x32M.qwak.models.management.ModelMetadata.AudienceRoutesGroupedByEnvironmentEntry\x12(\n\x06\x62uilds\x18\x06 \x03(\x0b\x32\x18.com.qwak.build.v1.Build\x1ai\n AudienceRoutesByEnvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.qwak.audience.v1.AudienceRoutesEntry:\x02\x38\x01\x1at\n\'AudienceRoutesGroupedByEnvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32).qwak.models.management.EnvironmentRoutes:\x02\x38\x01\"i\n CheckModelCreationAllowedRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x18\n\x10model_group_name\x18\x02 \x01(\t\x12\x19\n\x11jfrog_project_key\x18\x03 \x01(\t\"\x9b\x02\n!CheckModelCreationAllowedResponse\x12\x14\n\x0cis_creatable\x18\x01 \x01(\x08\x12;\n\x0cmodel_exists\x18\x02 \x01(\x0b\x32#.qwak.models.management.ModelExistsH\x00\x12\x42\n\x10model_not_exists\x18\x03 \x01(\x0b\x32&.qwak.models.management.ModelNotExistsH\x00\x12U\n\x1amodel_exists_with_mismatch\x18\x04 \x01(\x0b\x32/.qwak.models.management.ModelExistsWithMismatchH\x00\x42\x08\n\x06status\"\r\n\x0bModelExists\"\x10\n\x0eModelNotExists\"*\n\x17ModelExistsWithMismatch\x12\x0f\n\x07\x64\x65tails\x18\x01 \x03(\t*O\n\x15\x44\x65ploymentModelStatus\x12\x1d\n\x19\x44\x45PLOYMENT_STATUS_INVALID\x10\x00\x12\n\n\x06ONLINE\x10\x01\x12\x0b\n\x07OFFLINE\x10\x02*C\n\x0bModelStatus\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\r\n\tSUSPENDED\x10\x02\x12\x0c\n\x08\x44ISABLED\x10\x01*7\n\nMemoryUnit\x12\x17\n\x13MEMORY_UNIT_UNKNOWN\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02\x32\xec\x0c\n\x17ModelsManagementService\x12\x66\n\x0b\x43reateModel\x12*.qwak.models.management.CreateModelRequest\x1a+.qwak.models.management.CreateModelResponse\x12\x63\n\nListModels\x12).qwak.models.management.ListModelsRequest\x1a*.qwak.models.management.ListModelsResponse\x12~\n\x13ListModelsPaginated\x12\x32.qwak.models.management.ListModelsPaginatedRequest\x1a\x33.qwak.models.management.ListModelsPaginatedResponse\x12]\n\x08GetModel\x12\'.qwak.models.management.GetModelRequest\x1a(.qwak.models.management.GetModelResponse\x12w\n\x14ListModelsByModelIds\x12\x33.qwak.models.management.ListModelsByModelIdsRequest\x1a*.qwak.models.management.ListModelsResponse\x12\x66\n\x0b\x44\x65leteModel\x12*.qwak.models.management.DeleteModelRequest\x1a+.qwak.models.management.DeleteModelResponse\x12\x66\n\x0bUpdateModel\x12*.qwak.models.management.UpdateModelRequest\x1a+.qwak.models.management.UpdateModelResponse\x12n\n\x0c\x43reateBranch\x12+.qwak.models.management.CreateBranchRequest\x1a,.qwak.models.management.CreateBranchResponse\"\x03\x88\x02\x01\x12n\n\x0c\x44\x65leteBranch\x12+.qwak.models.management.DeleteBranchRequest\x1a,.qwak.models.management.DeleteBranchResponse\"\x03\x88\x02\x01\x12\x86\x01\n\x14GetDeploymentDetails\x12\x33.qwak.models.management.GetDeploymentDetailsRequest\x1a\x34.qwak.models.management.GetDeploymentDetailsResponse\"\x03\x88\x02\x01\x12l\n\rIsModelExists\x12,.qwak.models.management.IsModelExistsRequest\x1a-.qwak.models.management.IsModelExistsResponse\x12{\n\x12ListModelsMetadata\x12\x31.qwak.models.management.ListModelsMetadataRequest\x1a\x32.qwak.models.management.ListModelsMetadataResponse\x12u\n\x10GetModelMetadata\x12/.qwak.models.management.GetModelMetadataRequest\x1a\x30.qwak.models.management.GetModelMetadataResponse\x12\x90\x01\n\x19\x43heckModelCreationAllowed\x12\x38.qwak.models.management.CheckModelCreationAllowedRequest\x1a\x39.qwak.models.management.CheckModelCreationAllowedResponseB%\n!com.qwak.ai.management.models.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.models.models_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.management.models.apiP\001'
  _BRANCH.fields_by_name['deployed_build_id']._options = None
  _BRANCH.fields_by_name['deployed_build_id']._serialized_options = b'\030\001'
  _MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY._options = None
  _MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY._serialized_options = b'8\001'
  _MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY._options = None
  _MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY._serialized_options = b'8\001'
  _MODELMETADATA.fields_by_name['audience_routes_by_environment']._options = None
  _MODELMETADATA.fields_by_name['audience_routes_by_environment']._serialized_options = b'\030\001'
  _MODELMETADATA.fields_by_name['build']._options = None
  _MODELMETADATA.fields_by_name['build']._serialized_options = b'\030\001'
  _MODELSMANAGEMENTSERVICE.methods_by_name['CreateBranch']._options = None
  _MODELSMANAGEMENTSERVICE.methods_by_name['CreateBranch']._serialized_options = b'\210\002\001'
  _MODELSMANAGEMENTSERVICE.methods_by_name['DeleteBranch']._options = None
  _MODELSMANAGEMENTSERVICE.methods_by_name['DeleteBranch']._serialized_options = b'\210\002\001'
  _MODELSMANAGEMENTSERVICE.methods_by_name['GetDeploymentDetails']._options = None
  _MODELSMANAGEMENTSERVICE.methods_by_name['GetDeploymentDetails']._serialized_options = b'\210\002\001'
  _globals['_DEPLOYMENTMODELSTATUS']._serialized_start=5441
  _globals['_DEPLOYMENTMODELSTATUS']._serialized_end=5520
  _globals['_MODELSTATUS']._serialized_start=5522
  _globals['_MODELSTATUS']._serialized_end=5589
  _globals['_MEMORYUNIT']._serialized_start=5591
  _globals['_MEMORYUNIT']._serialized_end=5646
  _globals['_CREATEMODELREQUEST']._serialized_start=278
  _globals['_CREATEMODELREQUEST']._serialized_end=433
  _globals['_CREATEMODELRESPONSE']._serialized_start=435
  _globals['_CREATEMODELRESPONSE']._serialized_end=474
  _globals['_LISTMODELSREQUEST']._serialized_start=476
  _globals['_LISTMODELSREQUEST']._serialized_end=515
  _globals['_LISTMODELSRESPONSE']._serialized_start=517
  _globals['_LISTMODELSRESPONSE']._serialized_end=584
  _globals['_LISTMODELSPAGINATEDREQUEST']._serialized_start=587
  _globals['_LISTMODELSPAGINATEDREQUEST']._serialized_end=827
  _globals['_LISTMODELSPAGINATEDRESPONSE']._serialized_start=830
  _globals['_LISTMODELSPAGINATEDRESPONSE']._serialized_end=968
  _globals['_GETMODELREQUEST']._serialized_start=970
  _globals['_GETMODELREQUEST']._serialized_end=1043
  _globals['_GETMODELRESPONSE']._serialized_start=1045
  _globals['_GETMODELRESPONSE']._serialized_end=1109
  _globals['_LISTMODELSBYMODELIDSREQUEST']._serialized_start=1111
  _globals['_LISTMODELSBYMODELIDSREQUEST']._serialized_end=1180
  _globals['_DELETEMODELREQUEST']._serialized_start=1182
  _globals['_DELETEMODELREQUEST']._serialized_end=1240
  _globals['_DELETEMODELRESPONSE']._serialized_start=1242
  _globals['_DELETEMODELRESPONSE']._serialized_end=1263
  _globals['_UPDATEMODELREQUEST']._serialized_start=1265
  _globals['_UPDATEMODELREQUEST']._serialized_end=1378
  _globals['_UPDATEMODELRESPONSE']._serialized_start=1380
  _globals['_UPDATEMODELRESPONSE']._serialized_end=1456
  _globals['_CREATEBRANCHREQUEST']._serialized_start=1458
  _globals['_CREATEBRANCHREQUEST']._serialized_end=1518
  _globals['_CREATEBRANCHRESPONSE']._serialized_start=1520
  _globals['_CREATEBRANCHRESPONSE']._serialized_end=1561
  _globals['_DELETEBRANCHREQUEST']._serialized_start=1563
  _globals['_DELETEBRANCHREQUEST']._serialized_end=1603
  _globals['_DELETEBRANCHRESPONSE']._serialized_start=1605
  _globals['_DELETEBRANCHRESPONSE']._serialized_end=1627
  _globals['_ISMODELEXISTSREQUEST']._serialized_start=1629
  _globals['_ISMODELEXISTSREQUEST']._serialized_end=1707
  _globals['_ISMODELEXISTSRESPONSE']._serialized_start=1709
  _globals['_ISMODELEXISTSRESPONSE']._serialized_end=1748
  _globals['_MODELSPEC']._serialized_start=1751
  _globals['_MODELSPEC']._serialized_end=1969
  _globals['_MODELBRIEF']._serialized_start=1972
  _globals['_MODELBRIEF']._serialized_end=2299
  _globals['_MODELSPECCONFIGURATION']._serialized_start=2301
  _globals['_MODELSPECCONFIGURATION']._serialized_end=2352
  _globals['_MODEL']._serialized_start=2355
  _globals['_MODEL']._serialized_end=2983
  _globals['_MODELBUILDTYPE']._serialized_start=2986
  _globals['_MODELBUILDTYPE']._serialized_end=3136
  _globals['_SOURCE']._serialized_start=3138
  _globals['_SOURCE']._serialized_end=3146
  _globals['_MODELREGISTRYIMAGE']._serialized_start=3148
  _globals['_MODELREGISTRYIMAGE']._serialized_end=3199
  _globals['_BRANCH']._serialized_start=3202
  _globals['_BRANCH']._serialized_end=3437
  _globals['_BRANCH_BRANCHSTATUS']._serialized_start=3369
  _globals['_BRANCH_BRANCHSTATUS']._serialized_end=3437
  _globals['_GETDEPLOYMENTDETAILSREQUEST']._serialized_start=3439
  _globals['_GETDEPLOYMENTDETAILSREQUEST']._serialized_end=3505
  _globals['_GETDEPLOYMENTDETAILSRESPONSE']._serialized_start=3507
  _globals['_GETDEPLOYMENTDETAILSRESPONSE']._serialized_end=3608
  _globals['_DEPLOYMENTDETAILS']._serialized_start=3611
  _globals['_DEPLOYMENTDETAILS']._serialized_end=3886
  _globals['_LISTMODELSMETADATAREQUEST']._serialized_start=3888
  _globals['_LISTMODELSMETADATAREQUEST']._serialized_end=3935
  _globals['_LISTMODELSMETADATARESPONSE']._serialized_start=3937
  _globals['_LISTMODELSMETADATARESPONSE']._serialized_end=4028
  _globals['_GETMODELMETADATAREQUEST']._serialized_start=4030
  _globals['_GETMODELMETADATAREQUEST']._serialized_end=4073
  _globals['_GETMODELMETADATARESPONSE']._serialized_start=4075
  _globals['_GETMODELMETADATARESPONSE']._serialized_end=4164
  _globals['_ENVIRONMENTROUTES']._serialized_start=4166
  _globals['_ENVIRONMENTROUTES']._serialized_end=4270
  _globals['_MODELMETADATA']._serialized_start=4273
  _globals['_MODELMETADATA']._serialized_end=4969
  _globals['_MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY']._serialized_start=4746
  _globals['_MODELMETADATA_AUDIENCEROUTESBYENVIRONMENTENTRY']._serialized_end=4851
  _globals['_MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY']._serialized_start=4853
  _globals['_MODELMETADATA_AUDIENCEROUTESGROUPEDBYENVIRONMENTENTRY']._serialized_end=4969
  _globals['_CHECKMODELCREATIONALLOWEDREQUEST']._serialized_start=4971
  _globals['_CHECKMODELCREATIONALLOWEDREQUEST']._serialized_end=5076
  _globals['_CHECKMODELCREATIONALLOWEDRESPONSE']._serialized_start=5079
  _globals['_CHECKMODELCREATIONALLOWEDRESPONSE']._serialized_end=5362
  _globals['_MODELEXISTS']._serialized_start=5364
  _globals['_MODELEXISTS']._serialized_end=5377
  _globals['_MODELNOTEXISTS']._serialized_start=5379
  _globals['_MODELNOTEXISTS']._serialized_end=5395
  _globals['_MODELEXISTSWITHMISMATCH']._serialized_start=5397
  _globals['_MODELEXISTSWITHMISMATCH']._serialized_end=5439
  _globals['_MODELSMANAGEMENTSERVICE']._serialized_start=5649
  _globals['_MODELSMANAGEMENTSERVICE']._serialized_end=7293
# @@protoc_insertion_point(module_scope)
