# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/sinks/sink.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.sources import streaming_pb2 as qwak_dot_feature__store_dot_sources_dot_streaming__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/feature_store/sinks/sink.proto\x12\x18qwak.feature.store.sinks\x1a*qwak/feature_store/sources/streaming.proto\"\xb3\x01\n\rStreamingSink\x12L\n\x10\x61ttachment_point\x18\x01 \x01(\x0b\x32\x32.qwak.feature.store.sinks.StreamingAttachmentPoint\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x39\n\nkafka_sink\x18\x02 \x01(\x0b\x32#.qwak.feature.store.sinks.KafkaSinkH\x00\x42\x0b\n\tsink_type\"\xb9\x01\n\tKafkaSink\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x19\n\x11\x62ootstrap_servers\x18\x02 \x01(\t\x12\x41\n\x0emessage_format\x18\x03 \x01(\x0e\x32).qwak.feature.store.sources.MessageFormat\x12?\n\x0b\x61uth_config\x18\x04 \x01(\x0b\x32*.qwak.feature.store.sources.Authentication\" \n\x1eOnlineStreamingAttachmentPoint\"!\n\x1fOfflineStreamingAttachmentPoint\"\x83\x02\n\x18StreamingAttachmentPoint\x12\x65\n!online_streaming_attachment_point\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.sinks.OnlineStreamingAttachmentPointH\x00\x12g\n\"offline_streaming_attachment_point\x18\x02 \x01(\x0b\x32\x39.qwak.feature.store.sinks.OfflineStreamingAttachmentPointH\x00\x42\x17\n\x15\x61ttachment_point_typeBR\n#com.qwak.ai.feature.store.sinks.apiP\x01Z)qwak/featurestore/sinks;featurestoresinksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.sinks.sink_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.feature.store.sinks.apiP\001Z)qwak/featurestore/sinks;featurestoresinks'
  _globals['_STREAMINGSINK']._serialized_start=110
  _globals['_STREAMINGSINK']._serialized_end=289
  _globals['_KAFKASINK']._serialized_start=292
  _globals['_KAFKASINK']._serialized_end=477
  _globals['_ONLINESTREAMINGATTACHMENTPOINT']._serialized_start=479
  _globals['_ONLINESTREAMINGATTACHMENTPOINT']._serialized_end=511
  _globals['_OFFLINESTREAMINGATTACHMENTPOINT']._serialized_start=513
  _globals['_OFFLINESTREAMINGATTACHMENTPOINT']._serialized_end=546
  _globals['_STREAMINGATTACHMENTPOINT']._serialized_start=549
  _globals['_STREAMINGATTACHMENTPOINT']._serialized_end=808
# @@protoc_insertion_point(module_scope)
