# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/logging/log_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dqwak/logging/log_source.proto\x12\x14qwak.logging.service\"\xca\x04\n\tLogSource\x12\x41\n\rmodel_runtime\x18\x01 \x01(\x0b\x32(.qwak.logging.service.ModelRuntimeSourceH\x00\x12?\n\x0cremote_build\x18\x02 \x01(\x0b\x32\'.qwak.logging.service.RemoteBuildSourceH\x00\x12M\n\x13inference_execution\x18\x03 \x01(\x0b\x32..qwak.logging.service.InferenceExecutionSourceH\x00\x12P\n\x15streaming_feature_set\x18\x04 \x01(\x0b\x32/.qwak.logging.service.StreamingFeatureSetSourceH\x00\x12g\n!streaming_aggregation_feature_set\x18\x05 \x01(\x0b\x32:.qwak.logging.service.StreamingAggregationFeatureSetSourceH\x00\x12H\n\x11\x62\x61tch_feature_set\x18\x06 \x01(\x0b\x32+.qwak.logging.service.BatchFeatureSetSourceH\x00\x12[\n\x1breal_time_feature_extractor\x18\x07 \x01(\x0b\x32\x34.qwak.logging.service.RealTimeFeatureExtractorSourceH\x00\x42\x08\n\x06source\"\x92\x01\n\x11RemoteBuildSource\x12\x18\n\x10model_group_name\x18\x03 \x01(\t\x12\x16\n\nmodel_name\x18\x04 \x01(\tB\x02\x18\x01\x12\x12\n\x08model_id\x18\x05 \x01(\tH\x00\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x11\n\tphase_ids\x18\x02 \x03(\tB\x12\n\x10model_identifier\"\xa8\x01\n\x12ModelRuntimeSource\x12\x18\n\x10model_group_name\x18\x03 \x01(\t\x12\x16\n\nmodel_name\x18\x04 \x01(\tB\x02\x18\x01\x12\x12\n\x08model_id\x18\x05 \x01(\tH\x00\x12\x17\n\rdeployment_id\x18\x01 \x01(\tH\x01\x12\x12\n\x08\x62uild_id\x18\x02 \x01(\tH\x01\x42\x12\n\x10model_identifierB\x0b\n\tsearch_by\"\xba\x01\n\x18InferenceExecutionSource\x12\x18\n\x10model_group_name\x18\x03 \x01(\t\x12\x16\n\nmodel_name\x18\x04 \x01(\tB\x02\x18\x01\x12\x12\n\x08model_id\x18\x05 \x01(\tH\x00\x12\x1a\n\x10inference_job_id\x18\x01 \x01(\tH\x01\x12\x1b\n\x11inference_task_id\x18\x02 \x01(\tH\x01\x42\x12\n\x10model_identifierB\x0b\n\tsearch_by\"\xe4\x01\n\x19StreamingFeatureSetSource\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x05 \x01(\t\x12\x34\n\x07offline\x18\x03 \x01(\x0b\x32!.qwak.logging.service.OfflineTypeH\x00\x12\x32\n\x06online\x18\x04 \x01(\x0b\x32 .qwak.logging.service.OnlineTypeH\x00\x42\x06\n\x04type\"\xa4\x01\n\x15\x42\x61tchFeatureSetSource\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x04 \x01(\t\x12&\n\x1a\x66ilter_by_feature_set_name\x18\x05 \x01(\x08\x42\x02\x18\x01\x12\x0e\n\x06run_id\x18\x03 \x01(\t\"\xdb\x01\n$StreamingAggregationFeatureSetSource\x12\x37\n\trow_level\x18\x01 \x01(\x0b\x32\".qwak.logging.service.RowLevelTypeH\x00\x12:\n\ncompaction\x18\x02 \x01(\x0b\x32$.qwak.logging.service.CompactionTypeH\x00\x12\x36\n\x08\x62\x61\x63kfill\x18\x03 \x01(\x0b\x32\".qwak.logging.service.BackfillTypeH\x00\x42\x06\n\x04type\"c\n\nOnlineType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x03 \x01(\t\"t\n\x0bOfflineType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x04 \x01(\t\x12\x0e\n\x06run_id\x18\x03 \x01(\t\"e\n\x0cRowLevelType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x03 \x01(\t\"w\n\x0e\x43ompactionType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x04 \x01(\t\x12\x0e\n\x06run_id\x18\x03 \x01(\t\"e\n\x0c\x42\x61\x63kfillType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12#\n\x1b\x66\x65\x61ture_set_repository_name\x18\x03 \x01(\t\"H\n\x1eRealTimeFeatureExtractorSource\x12&\n\x1ereal_time_feature_extractor_id\x18\x01 \x01(\tB,\n\x1e\x63om.qwak.ai.logging.reader.apiP\x01Z\x08/loggingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.logging.log_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.logging.reader.apiP\001Z\010/logging'
  _REMOTEBUILDSOURCE.fields_by_name['model_name']._options = None
  _REMOTEBUILDSOURCE.fields_by_name['model_name']._serialized_options = b'\030\001'
  _MODELRUNTIMESOURCE.fields_by_name['model_name']._options = None
  _MODELRUNTIMESOURCE.fields_by_name['model_name']._serialized_options = b'\030\001'
  _INFERENCEEXECUTIONSOURCE.fields_by_name['model_name']._options = None
  _INFERENCEEXECUTIONSOURCE.fields_by_name['model_name']._serialized_options = b'\030\001'
  _BATCHFEATURESETSOURCE.fields_by_name['filter_by_feature_set_name']._options = None
  _BATCHFEATURESETSOURCE.fields_by_name['filter_by_feature_set_name']._serialized_options = b'\030\001'
  _globals['_LOGSOURCE']._serialized_start=56
  _globals['_LOGSOURCE']._serialized_end=642
  _globals['_REMOTEBUILDSOURCE']._serialized_start=645
  _globals['_REMOTEBUILDSOURCE']._serialized_end=791
  _globals['_MODELRUNTIMESOURCE']._serialized_start=794
  _globals['_MODELRUNTIMESOURCE']._serialized_end=962
  _globals['_INFERENCEEXECUTIONSOURCE']._serialized_start=965
  _globals['_INFERENCEEXECUTIONSOURCE']._serialized_end=1151
  _globals['_STREAMINGFEATURESETSOURCE']._serialized_start=1154
  _globals['_STREAMINGFEATURESETSOURCE']._serialized_end=1382
  _globals['_BATCHFEATURESETSOURCE']._serialized_start=1385
  _globals['_BATCHFEATURESETSOURCE']._serialized_end=1549
  _globals['_STREAMINGAGGREGATIONFEATURESETSOURCE']._serialized_start=1552
  _globals['_STREAMINGAGGREGATIONFEATURESETSOURCE']._serialized_end=1771
  _globals['_ONLINETYPE']._serialized_start=1773
  _globals['_ONLINETYPE']._serialized_end=1872
  _globals['_OFFLINETYPE']._serialized_start=1874
  _globals['_OFFLINETYPE']._serialized_end=1990
  _globals['_ROWLEVELTYPE']._serialized_start=1992
  _globals['_ROWLEVELTYPE']._serialized_end=2093
  _globals['_COMPACTIONTYPE']._serialized_start=2095
  _globals['_COMPACTIONTYPE']._serialized_end=2214
  _globals['_BACKFILLTYPE']._serialized_start=2216
  _globals['_BACKFILLTYPE']._serialized_end=2317
  _globals['_REALTIMEFEATUREEXTRACTORSOURCE']._serialized_start=2319
  _globals['_REALTIMEFEATUREEXTRACTORSOURCE']._serialized_end=2391
# @@protoc_insertion_point(module_scope)
