# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/vectors/v1/collection/collection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/vectors/v1/collection/collection.proto\x12\x1fqwak.vector.store.v1.collection\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa2\x01\n\x0cQwakMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x34\n\x10last_modified_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x04 \x01(\t\"?\n\x1aVectorCollectionVectorizer\x12\x19\n\x0fqwak_model_name\x18\x01 \x01(\tH\x00\x42\x06\n\x04type\"\x85\x02\n\x14VectorCollectionSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12O\n\nvectorizer\x18\x03 \x01(\x0b\x32;.qwak.vector.store.v1.collection.VectorCollectionVectorizer\x12G\n\x06metric\x18\x04 \x01(\x0e\x32\x37.qwak.vector.store.v1.collection.VectorCollectionMetric\x12\x11\n\tdimension\x18\x05 \x01(\x05\x12\x1d\n\x15multi_tenancy_enabled\x18\x06 \x01(\x08\"x\n\x1aVectorCollectionDefinition\x12\n\n\x02id\x18\x01 \x01(\t\x12N\n\x0f\x63ollection_spec\x18\x02 \x01(\x0b\x32\x35.qwak.vector.store.v1.collection.VectorCollectionSpec\"\xed\x01\n\x10VectorCollection\x12?\n\x08metadata\x18\x01 \x01(\x0b\x32-.qwak.vector.store.v1.collection.QwakMetadata\x12O\n\ndefinition\x18\x02 \x01(\x0b\x32;.qwak.vector.store.v1.collection.VectorCollectionDefinition\x12G\n\x06status\x18\x03 \x01(\x0e\x32\x37.qwak.vector.store.v1.collection.VectorCollectionStatus\"Z\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12@\n\tdata_type\x18\x02 \x01(\x0e\x32-.qwak.vector.store.v1.collection.PropertyType\"h\n\x12\x43ollectionMetadata\x12\x13\n\x0bnum_vectors\x18\x01 \x01(\x03\x12=\n\nproperties\x18\x02 \x03(\x0b\x32).qwak.vector.store.v1.collection.Property*\x8f\x02\n\x16VectorCollectionStatus\x12\x1d\n\x19\x43OLLECTION_STATUS_INVALID\x10\x00\x12&\n\"COLLECTION_STATUS_CREATE_REQUESTED\x10\x01\x12\x1d\n\x19\x43OLLECTION_STATUS_CREATED\x10\x02\x12#\n\x1f\x43OLLECTION_STATUS_CREATE_FAILED\x10\x03\x12&\n\"COLLECTION_STATUS_DELETE_REQUESTED\x10\x04\x12#\n\x1f\x43OLLECTION_STATUS_DELETE_FAILED\x10\x05\x12\x1d\n\x19\x43OLLECTION_STATUS_DELETED\x10\x06*\xd3\x01\n\x16VectorCollectionMetric\x12\x1d\n\x19\x43OLLECTION_METRIC_INVALID\x10\x00\x12 \n\x1c\x43OLLECTION_METRIC_L2_SQUARED\x10\x01\x12\x1c\n\x18\x43OLLECTION_METRIC_COSINE\x10\x02\x12!\n\x1d\x43OLLECTION_METRIC_DOT_PRODUCT\x10\x03\x12\x18\n\x14\x43OLLECTION_METRIC_L1\x10\x04\x12\x1d\n\x19\x43OLLECTION_METRIC_HAMMING\x10\x05*\xac\x01\n\x0cPropertyType\x12\x19\n\x15PROPERTY_TYPE_INVALID\x10\x00\x12\x18\n\x14PROPERTY_TYPE_STRING\x10\x01\x12\x15\n\x11PROPERTY_TYPE_INT\x10\x02\x12\x18\n\x14PROPERTY_TYPE_DOUBLE\x10\x03\x12\x19\n\x15PROPERTY_TYPE_BOOLEAN\x10\x04\x12\x1b\n\x17PROPERTY_TYPE_TIMESTAMP\x10\x05\x42K\n!com.qwak.ai.vectors.v1.collectionP\x01Z$qwak/vector_management/v1;collectionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.vectors.v1.collection.collection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.vectors.v1.collectionP\001Z$qwak/vector_management/v1;collection'
  _globals['_VECTORCOLLECTIONSTATUS']._serialized_start=1168
  _globals['_VECTORCOLLECTIONSTATUS']._serialized_end=1439
  _globals['_VECTORCOLLECTIONMETRIC']._serialized_start=1442
  _globals['_VECTORCOLLECTIONMETRIC']._serialized_end=1653
  _globals['_PROPERTYTYPE']._serialized_start=1656
  _globals['_PROPERTYTYPE']._serialized_end=1828
  _globals['_QWAKMETADATA']._serialized_start=114
  _globals['_QWAKMETADATA']._serialized_end=276
  _globals['_VECTORCOLLECTIONVECTORIZER']._serialized_start=278
  _globals['_VECTORCOLLECTIONVECTORIZER']._serialized_end=341
  _globals['_VECTORCOLLECTIONSPEC']._serialized_start=344
  _globals['_VECTORCOLLECTIONSPEC']._serialized_end=605
  _globals['_VECTORCOLLECTIONDEFINITION']._serialized_start=607
  _globals['_VECTORCOLLECTIONDEFINITION']._serialized_end=727
  _globals['_VECTORCOLLECTION']._serialized_start=730
  _globals['_VECTORCOLLECTION']._serialized_end=967
  _globals['_PROPERTY']._serialized_start=969
  _globals['_PROPERTY']._serialized_end=1059
  _globals['_COLLECTIONMETADATA']._serialized_start=1061
  _globals['_COLLECTIONMETADATA']._serialized_end=1165
# @@protoc_insertion_point(module_scope)
