# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/auto_scaling/v1/auto_scaling_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.auto_scaling.v1 import auto_scaling_pb2 as qwak_dot_auto__scaling_dot_v1_dot_auto__scaling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/qwak/auto_scaling/v1/auto_scaling_service.proto\x12\x14qwak.auto_scaling.v1\x1a\'qwak/auto_scaling/v1/auto_scaling.proto\"\x8a\x01\n\x18\x41ttachAutoScalingRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x16\n\x0evariation_name\x18\x02 \x01(\t\x12\x44\n\x13\x61uto_scaling_config\x18\x03 \x01(\x0b\x32\'.qwak.auto_scaling.v1.AutoScalingConfig\"4\n\x19\x41ttachAutoScalingResponse\x12\x17\n\x0f\x61uto_scaling_id\x18\x01 \x01(\t2\x8a\x01\n\x12\x41utoScalingService\x12t\n\x11\x41ttachAutoScaling\x12..qwak.auto_scaling.v1.AttachAutoScalingRequest\x1a/.qwak.auto_scaling.v1.AttachAutoScalingResponseBK\n%com.qwak.ai.management.deployment.apiP\x01Z qwak/auto_scaling/v1;autoscalingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.auto_scaling.v1.auto_scaling_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001Z qwak/auto_scaling/v1;autoscaling'
  _globals['_ATTACHAUTOSCALINGREQUEST']._serialized_start=115
  _globals['_ATTACHAUTOSCALINGREQUEST']._serialized_end=253
  _globals['_ATTACHAUTOSCALINGRESPONSE']._serialized_start=255
  _globals['_ATTACHAUTOSCALINGRESPONSE']._serialized_end=307
  _globals['_AUTOSCALINGSERVICE']._serialized_start=310
  _globals['_AUTOSCALINGSERVICE']._serialized_end=448
# @@protoc_insertion_point(module_scope)
