# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/feature_store/jobs/v1/job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$qwak/feature_store/jobs/v1/job.proto\x12\x1aqwak.feature.store.jobs.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc9\x03\n\tJobRecord\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0e\n\x06run_id\x18\x02 \x01(\x03\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x03 \x01(\t\x12\x15\n\rfeatureset_id\x18\x04 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\x12\x12\n\ntry_number\x18\x06 \x01(\x05\x12\x37\n\tjob_state\x18\x07 \x01(\x0e\x32$.qwak.feature.store.jobs.v1.JobState\x12\x31\n\rcreation_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstart_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x45\n\x10ingestion_window\x18\x0b \x01(\x0b\x32+.qwak.feature.store.jobs.v1.IngestionWindow\x12\x14\n\x0c\x65xecution_id\x18\x0c \x01(\x03\x12\x19\n\x11ingestion_message\x18\r \x01(\t\"\xed\x01\n\x0fIngestionWindow\x12<\n\x18ingested_data_start_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16ingested_data_end_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\"\n\x1aingested_data_updated_rows\x18\x03 \x01(\x05\x12<\n\x18scheduled_execution_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"T\n\x1a\x46\x65\x61turesetLevelJobsSummary\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x1f\n\x17total_num_affected_rows\x18\x02 \x01(\x03*[\n\x08JobState\x12\x0b\n\x07INVALID\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\r\n\tTOO_EARLY\x10\x05\x42=\n%com.qwak.ai.feature.store.jobs.v1.apiP\x01Z\x12qwak/fsjobs;fsjobsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.feature_store.jobs.v1.job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.feature.store.jobs.v1.apiP\001Z\022qwak/fsjobs;fsjobs'
  _globals['_JOBSTATE']._serialized_start=887
  _globals['_JOBSTATE']._serialized_end=978
  _globals['_JOBRECORD']._serialized_start=102
  _globals['_JOBRECORD']._serialized_end=559
  _globals['_INGESTIONWINDOW']._serialized_start=562
  _globals['_INGESTIONWINDOW']._serialized_end=799
  _globals['_FEATURESETLEVELJOBSSUMMARY']._serialized_start=801
  _globals['_FEATURESETLEVELJOBSSUMMARY']._serialized_end=885
# @@protoc_insertion_point(module_scope)
