# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/container_registry_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.creds import secret_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_creds_dot_secret__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLqwak/administration/runtime_configuration/v0/container_registry_config.proto\x12\x46qwak.administration.runtime_configuration.v0.container_registry_config\x1a?qwak/administration/runtime_configuration/v0/creds/secret.proto\"\x97\x01\n\x1e\x43ontainerRegistryConfiguration\x12u\n\x04\x61uth\x18\x01 \x01(\x0b\x32g.qwak.administration.runtime_configuration.v0.container_registry_config.ContainerRegistryAuthentication\"\xa4\x01\n\x1f\x43ontainerRegistryAuthentication\x12t\n\x11image_pull_secret\x18\x01 \x01(\x0b\x32W.qwak.administration.runtime_configuration.v0.container_registry_config.ImagePullSecretH\x00\x42\x0b\n\tauth_type\"j\n\x0fImagePullSecret\x12W\n\x06secret\x18\x01 \x01(\x0b\x32G.qwak.administration.runtime_configuration.v0.creds.secret.SecretKeyRefB\xe6\x01\n?com.jfrog.ml.runtime_configuration.v0.container_registry_configP\x01Z\xa0\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.container_registry_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?com.jfrog.ml.runtime_configuration.v0.container_registry_configP\001Z\240\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0;runtime_configuration_v0'
  _globals['_CONTAINERREGISTRYCONFIGURATION']._serialized_start=218
  _globals['_CONTAINERREGISTRYCONFIGURATION']._serialized_end=369
  _globals['_CONTAINERREGISTRYAUTHENTICATION']._serialized_start=372
  _globals['_CONTAINERREGISTRYAUTHENTICATION']._serialized_end=536
  _globals['_IMAGEPULLSECRET']._serialized_start=538
  _globals['_IMAGEPULLSECRET']._serialized_end=644
# @@protoc_insertion_point(module_scope)
