"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.feature_store.jobs.job_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ApplyJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RECORD_FIELD_NUMBER: builtins.int
    LOGS_PATH_FIELD_NUMBER: builtins.int
    PARTNER_ID_FIELD_NUMBER: builtins.int
    ERROR_TECHNICAL_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def job_record(self) -> qwak.feature_store.jobs.job_pb2.JobRecord:
        """The job record to register"""
    logs_path: builtins.str
    """The path of the jobs logs"""
    partner_id: builtins.str
    """The jobs' partner id"""
    error_technical_details: builtins.str
    """Error technical details"""
    def __init__(
        self,
        *,
        job_record: qwak.feature_store.jobs.job_pb2.JobRecord | None = ...,
        logs_path: builtins.str = ...,
        partner_id: builtins.str = ...,
        error_technical_details: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job_record", b"job_record"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error_technical_details", b"error_technical_details", "job_record", b"job_record", "logs_path", b"logs_path", "partner_id", b"partner_id"]) -> None: ...

global___ApplyJobRequest = ApplyJobRequest

class ApplyJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_RUNNING_ID_FIELD_NUMBER: builtins.int
    job_running_id: builtins.int
    def __init__(
        self,
        *,
        job_running_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_running_id", b"job_running_id"]) -> None: ...

global___ApplyJobResponse = ApplyJobResponse

class InitPaginationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """The feature set name of the requested job records"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___InitPaginationRequest = InitPaginationRequest

class InitPaginationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_COUNT_FIELD_NUMBER: builtins.int
    LAST_ID_FIELD_NUMBER: builtins.int
    record_count: builtins.int
    """The amount of records that exist for this pagination session (current total amount of records for the feature set)"""
    last_id: builtins.int
    """The record to use for the after-id in the ListJobs request (gives the actual latest record running_id + 1)"""
    def __init__(
        self,
        *,
        record_count: builtins.int = ...,
        last_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_id", b"last_id", "record_count", b"record_count"]) -> None: ...

global___InitPaginationResponse = InitPaginationResponse

class ListJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    AFTER_ID_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """The feature set name of the requested job records"""
    page_size: builtins.int
    """The amount of records to send in the result set"""
    page_number: builtins.int
    """The page number to get"""
    after_id: builtins.int
    """The record id from which we retrieve the data, if unset (defaults to 0) we return the first records"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
        page_size: builtins.int = ...,
        page_number: builtins.int = ...,
        after_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["after_id", b"after_id", "feature_set_name", b"feature_set_name", "page_number", b"page_number", "page_size", b"page_size"]) -> None: ...

global___ListJobsRequest = ListJobsRequest

class ListJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.feature_store.jobs.job_pb2.ElaborateJobRecord]:
        """Result set of the requested jobs"""
    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[qwak.feature_store.jobs.job_pb2.ElaborateJobRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["jobs", b"jobs"]) -> None: ...

global___ListJobsResponse = ListJobsResponse

class GetJobLogsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """The job id of which the logs are requested"""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_id", b"job_id"]) -> None: ...

global___GetJobLogsRequest = GetJobLogsRequest

class GetJobLogsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGS_FOLDER_PATH_FIELD_NUMBER: builtins.int
    logs_folder_path: builtins.str
    """The S3 path of the logs folder"""
    def __init__(
        self,
        *,
        logs_folder_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["logs_folder_path", b"logs_folder_path"]) -> None: ...

global___GetJobLogsResponse = GetJobLogsResponse

class GetLatestSuccessfulJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    PARTNER_ID_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """The feature set name of the requested latest successful job record"""
    partner_id: builtins.str
    """The jobs' partner id"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
        partner_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name", "partner_id", b"partner_id"]) -> None: ...

global___GetLatestSuccessfulJobRequest = GetLatestSuccessfulJobRequest

class GetLatestSuccessfulJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_FIELD_NUMBER: builtins.int
    FOUND_FIELD_NUMBER: builtins.int
    @property
    def job(self) -> qwak.feature_store.jobs.job_pb2.ElaborateJobRecord:
        """the requested job"""
    found: builtins.bool
    """is the job empty or not"""
    def __init__(
        self,
        *,
        job: qwak.feature_store.jobs.job_pb2.ElaborateJobRecord | None = ...,
        found: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job", b"job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["found", b"found", "job", b"job"]) -> None: ...

global___GetLatestSuccessfulJobResponse = GetLatestSuccessfulJobResponse

class DeleteFeatureSetJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_NAME_FIELD_NUMBER: builtins.int
    feature_set_name: builtins.str
    """The feature set name of the requested delete feature set jobs"""
    def __init__(
        self,
        *,
        feature_set_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_name", b"feature_set_name"]) -> None: ...

global___DeleteFeatureSetJobsRequest = DeleteFeatureSetJobsRequest

class DeleteFeatureSetJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_JOB_RECORDS_COUNT_FIELD_NUMBER: builtins.int
    deleted_job_records_count: builtins.int
    def __init__(
        self,
        *,
        deleted_job_records_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deleted_job_records_count", b"deleted_job_records_count"]) -> None: ...

global___DeleteFeatureSetJobsResponse = DeleteFeatureSetJobsResponse
