"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PodStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_STATUSES_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    POD_ID_FIELD_NUMBER: builtins.int
    @property
    def container_statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ContainerStatus]: ...
    message: builtins.str
    phase: builtins.str
    reason: builtins.str
    start_time: builtins.str
    pod_id: builtins.str
    def __init__(
        self,
        *,
        container_statuses: collections.abc.Iterable[global___ContainerStatus] | None = ...,
        message: builtins.str = ...,
        phase: builtins.str = ...,
        reason: builtins.str = ...,
        start_time: builtins.str = ...,
        pod_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_statuses", b"container_statuses", "message", b"message", "phase", b"phase", "pod_id", b"pod_id", "reason", b"reason", "start_time", b"start_time"]) -> None: ...

global___PodStatus = PodStatus

class ContainerStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    RESTART_COUNT_FIELD_NUMBER: builtins.int
    STARTED_FIELD_NUMBER: builtins.int
    CONTAINER_STATE_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    image: builtins.str
    restart_count: builtins.int
    started: builtins.bool
    @property
    def container_state(self) -> global___ContainerState: ...
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        image: builtins.str = ...,
        restart_count: builtins.int = ...,
        started: builtins.bool = ...,
        container_state: global___ContainerState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_state", b"container_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_id", b"container_id", "container_state", b"container_state", "image", b"image", "restart_count", b"restart_count", "started", b"started"]) -> None: ...

global___ContainerStatus = ContainerStatus

class ContainerState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_STATE_RUNNING_FIELD_NUMBER: builtins.int
    CONTAINER_STATE_TERMINATED_FIELD_NUMBER: builtins.int
    CONTAINER_STATE_WAITING_FIELD_NUMBER: builtins.int
    @property
    def container_state_running(self) -> global___ContainerStateRunning: ...
    @property
    def container_state_terminated(self) -> global___ContainerStateTerminated: ...
    @property
    def container_state_waiting(self) -> global___ContainerStateWaiting: ...
    def __init__(
        self,
        *,
        container_state_running: global___ContainerStateRunning | None = ...,
        container_state_terminated: global___ContainerStateTerminated | None = ...,
        container_state_waiting: global___ContainerStateWaiting | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["container_state_running", b"container_state_running", "container_state_terminated", b"container_state_terminated", "container_state_waiting", b"container_state_waiting", "state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_state_running", b"container_state_running", "container_state_terminated", b"container_state_terminated", "container_state_waiting", b"container_state_waiting", "state", b"state"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["state", b"state"]) -> typing_extensions.Literal["container_state_running", "container_state_terminated", "container_state_waiting"] | None: ...

global___ContainerState = ContainerState

class ContainerStateRunning(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STARTED_AT_FIELD_NUMBER: builtins.int
    started_at: builtins.str
    def __init__(
        self,
        *,
        started_at: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["started_at", b"started_at"]) -> None: ...

global___ContainerStateRunning = ContainerStateRunning

class ContainerStateTerminated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    EXIT_CODE_FIELD_NUMBER: builtins.int
    FINISHED_AT_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    SIGNAL_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    exit_code: builtins.int
    finished_at: builtins.str
    message: builtins.str
    reason: builtins.str
    signal: builtins.int
    started_at: builtins.str
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        exit_code: builtins.int = ...,
        finished_at: builtins.str = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        signal: builtins.int = ...,
        started_at: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_id", b"container_id", "exit_code", b"exit_code", "finished_at", b"finished_at", "message", b"message", "reason", b"reason", "signal", b"signal", "started_at", b"started_at"]) -> None: ...

global___ContainerStateTerminated = ContainerStateTerminated

class ContainerStateWaiting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    message: builtins.str
    reason: builtins.str
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "reason", b"reason"]) -> None: ...

global___ContainerStateWaiting = ContainerStateWaiting
