"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DataCatalogConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GLUE_FIELD_NUMBER: builtins.int
    BIG_LAKE_FIELD_NUMBER: builtins.int
    UNITY_CATALOG_FIELD_NUMBER: builtins.int
    @property
    def glue(self) -> global___GlueConfiguration: ...
    @property
    def big_lake(self) -> global___BigLakeConfiguration: ...
    @property
    def unity_catalog(self) -> global___UnityCatalogConfiguration: ...
    def __init__(
        self,
        *,
        glue: global___GlueConfiguration | None = ...,
        big_lake: global___BigLakeConfiguration | None = ...,
        unity_catalog: global___UnityCatalogConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["big_lake", b"big_lake", "glue", b"glue", "type", b"type", "unity_catalog", b"unity_catalog"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["big_lake", b"big_lake", "glue", b"glue", "type", b"type", "unity_catalog", b"unity_catalog"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["glue", "big_lake", "unity_catalog"] | None: ...

global___DataCatalogConfiguration = DataCatalogConfiguration

class BigLakeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    BIG_LAKE_CONNECTION_NAME_FIELD_NUMBER: builtins.int
    BIG_LAKE_LOCATION_FIELD_NUMBER: builtins.int
    CATALOG_NAME_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    big_lake_connection_name: builtins.str
    big_lake_location: builtins.str
    catalog_name: builtins.str
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        big_lake_connection_name: builtins.str = ...,
        big_lake_location: builtins.str = ...,
        catalog_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["big_lake_connection_name", b"big_lake_connection_name", "big_lake_location", b"big_lake_location", "catalog_name", b"catalog_name", "project_id", b"project_id"]) -> None: ...

global___BigLakeConfiguration = BigLakeConfiguration

class GlueConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___GlueConfiguration = GlueConfiguration

class UnityCatalogConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOG_NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    catalog_name: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        catalog_name: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_name", b"catalog_name", "url", b"url"]) -> None: ...

global___UnityCatalogConfiguration = UnityCatalogConfiguration
