# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/deployment/deployment_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.deployment import deployment_pb2 as qwak_dot_deployment_dot_deployment__pb2
from _qwak_proto.qwak.auto_scaling.v1 import auto_scaling_pb2 as qwak_dot_auto__scaling_dot_v1_dot_auto__scaling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(qwak/deployment/deployment_service.proto\x12\x1aqwak.deployment.management\x1a qwak/deployment/deployment.proto\x1a\'qwak/auto_scaling/v1/auto_scaling.proto\"\x86\x03\n\x12\x44\x65ployModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x14\n\x08\x62uild_id\x18\x03 \x01(\tB\x02\x18\x01\x12G\n\x0fhosting_service\x18\x04 \x01(\x0b\x32*.qwak.deployment.management.HostingServiceB\x02\x18\x01\x12n\n\x19\x65nvironment_to_deployment\x18\x05 \x03(\x0b\x32K.qwak.deployment.management.DeployModelRequest.EnvironmentToDeploymentEntry\x1ax\n\x1c\x45nvironmentToDeploymentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12G\n\x05value\x18\x02 \x01(\x0b\x32\x38.qwak.deployment.management.EnvironmentDeploymentMessage:\x02\x38\x01\"\x94\x03\n\x13\x44\x65ployModelResponse\x12\x1f\n\x13\x64\x65ployment_named_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x45\n\x06status\x18\x02 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatusB\x02\x18\x01\x12\x10\n\x04info\x18\x03 \x01(\tB\x02\x18\x01\x12|\n environment_to_deployment_result\x18\x04 \x03(\x0b\x32R.qwak.deployment.management.DeployModelResponse.EnvironmentToDeploymentResultEntry\x1a\x84\x01\n\"EnvironmentToDeploymentResultEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12M\n\x05value\x18\x02 \x01(\x0b\x32>.qwak.deployment.management.EnvironmentDeploymentResultMessage:\x02\x38\x01\"\x86\x04\n\x14UndeployModelRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12Z\n\x14hosting_service_type\x18\x03 \x01(\x0e\x32\x38.qwak.deployment.management.DeploymentHostingServiceTypeB\x02\x18\x01\x12\x45\n\x0etraffic_config\x18\x04 \x01(\x0b\x32).qwak.deployment.management.TrafficConfigB\x02\x18\x01\x12\x1a\n\x0evariation_name\x18\x05 \x01(\tB\x02\x18\x01\x12t\n\x1b\x65nvironment_to_undeployment\x18\x06 \x03(\x0b\x32O.qwak.deployment.management.UndeployModelRequest.EnvironmentToUndeploymentEntry\x12\x12\n\nmodel_uuid\x18\x07 \x01(\t\x1a|\n\x1e\x45nvironmentToUndeploymentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.qwak.deployment.management.EnvironmentUndeploymentMessage:\x02\x38\x01\"\x80\x03\n\x15UndeployModelResponse\x12\x45\n\x06status\x18\x01 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatusB\x02\x18\x01\x12\x10\n\x04info\x18\x02 \x01(\tB\x02\x18\x01\x12\x82\x01\n\"environment_to_undeployment_result\x18\x03 \x03(\x0b\x32V.qwak.deployment.management.UndeployModelResponse.EnvironmentToUndeploymentResultEntry\x1a\x88\x01\n$EnvironmentToUndeploymentResultEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12O\n\x05value\x18\x02 \x01(\x0b\x32@.qwak.deployment.management.EnvironmentUndeploymentResultMessage:\x02\x38\x01\"-\n\x14GetDeploymentRequest\x12\x15\n\rdeployment_id\x18\x01 \x01(\t\"\xbb\x01\n\x15GetDeploymentResponse\x12J\n\x13\x64\x65ployments_details\x18\x01 \x01(\x0b\x32-.qwak.deployment.management.DeploymentDetails\x12V\n\x19\x64\x65ployment_phases_details\x18\x02 \x01(\x0b\x32\x33.qwak.deployment.management.DeploymentPhasesDetails\"\x95\x01\n\x1aGetDeploymentStatusRequest\x12\x1b\n\x13\x64\x65ployment_named_id\x18\x01 \x01(\t\x12Z\n\x14hosting_service_type\x18\x02 \x01(\x0e\x32\x38.qwak.deployment.management.DeploymentHostingServiceTypeB\x02\x18\x01\"`\n\x1bGetDeploymentStatusResponse\x12\x41\n\x06status\x18\x01 \x01(\x0e\x32\x31.qwak.deployment.management.ModelDeploymentStatus\"\x97\x04\n&UpdateDeploymentRuntimeSettingsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12V\n\x13\x64\x65ployment_settings\x18\x03 \x01(\x0b\x32\x35.qwak.deployment.management.RuntimeDeploymentSettingsB\x02\x18\x01\x12\x1a\n\x0evariation_name\x18\x04 \x01(\tB\x02\x18\x01\x12\xa2\x01\n*environment_to_runtime_deployment_settings\x18\x05 \x03(\x0b\x32n.qwak.deployment.management.UpdateDeploymentRuntimeSettingsRequest.EnvironmentToRuntimeDeploymentSettingsEntry\x12\x12\n\nmodel_uuid\x18\x06 \x01(\t\x1a\x96\x01\n+EnvironmentToRuntimeDeploymentSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12V\n\x05value\x18\x02 \x01(\x0b\x32G.qwak.deployment.management.EnvironmentRuntimeDeploymentSettingsMessage:\x02\x38\x01\"\x87\x03\n\'UpdateDeploymentRuntimeSettingsResponse\x12\xb4\x01\n3environment_to_runtime_deployment_settings_response\x18\x01 \x03(\x0b\x32w.qwak.deployment.management.UpdateDeploymentRuntimeSettingsResponse.EnvironmentToRuntimeDeploymentSettingsResponseEntry\x1a\xa4\x01\n3EnvironmentToRuntimeDeploymentSettingsResponseEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\\\n\x05value\x18\x02 \x01(\x0b\x32M.qwak.deployment.management.EnvironmentRuntimeDeploymentSettingsResultMessage:\x02\x38\x01\"Z\n\x1bGetDeploymentDetailsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x12\n\nmodel_uuid\x18\x03 \x01(\t\"\xec\x06\n\x1cGetDeploymentDetailsResponse\x12U\n\x1a\x63urrent_deployment_details\x18\x01 \x01(\x0b\x32-.qwak.deployment.management.DeploymentDetailsB\x02\x18\x01\x12N\n\x15last_deployment_brief\x18\x02 \x01(\x0b\x32+.qwak.deployment.management.DeploymentBriefB\x02\x18\x01\x12V\n\x1b\x63urrent_deployments_details\x18\x03 \x03(\x0b\x32-.qwak.deployment.management.DeploymentDetailsB\x02\x18\x01\x12\x87\x01\n!environment_to_deployment_details\x18\x04 \x03(\x0b\x32\\.qwak.deployment.management.GetDeploymentDetailsResponse.EnvironmentToDeploymentDetailsEntry\x12\x1d\n\x11multi_env_support\x18\x05 \x01(\x08\x42\x02\x18\x01\x12\x90\x01\n&build_to_environment_deployment_status\x18\x06 \x03(\x0b\x32`.qwak.deployment.management.GetDeploymentDetailsResponse.BuildToEnvironmentDeploymentStatusEntry\x1a\x86\x01\n#EnvironmentToDeploymentDetailsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12N\n\x05value\x18\x02 \x01(\x0b\x32?.qwak.deployment.management.EnvironmentDeploymentDetailsMessage:\x02\x38\x01\x1a\x87\x01\n\'BuildToEnvironmentDeploymentStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12K\n\x05value\x18\x02 \x01(\x0b\x32<.qwak.deployment.management.BuildDeploymentEnvironmentStatus:\x02\x38\x01\"k\n\x1bGetDeploymentHistoryRequest\x12\x15\n\tbranch_id\x18\x01 \x01(\tB\x02\x18\x01\x12\x14\n\nmodel_uuid\x18\x02 \x01(\tH\x00\x12\x12\n\x08\x62uild_id\x18\x03 \x01(\tH\x00\x42\x0b\n\tfilter_by\"\xf7\x02\n\x1cGetDeploymentHistoryResponse\x12@\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32+.qwak.deployment.management.DeploymentBrief\x12\x8b\x01\n!environment_to_deployment_history\x18\x02 \x03(\x0b\x32\\.qwak.deployment.management.GetDeploymentHistoryResponse.EnvironmentToDeploymentHistoryEntryB\x02\x18\x01\x1a\x86\x01\n#EnvironmentToDeploymentHistoryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12N\n\x05value\x18\x02 \x01(\x0b\x32?.qwak.deployment.management.EnvironmentDeploymentHistoryMessage:\x02\x38\x01\"\x95\x01\n%PushEnvironmentDeploymentStateRequest\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\x12T\n\x10\x64\x65ployment_state\x18\x02 \x03(\x0b\x32:.qwak.deployment.management.KubernetesModelDeploymentState\"(\n&PushEnvironmentDeploymentStateResponse\"\x80\x01\n\x18\x41pplyModelTrafficRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x39\n\nvariations\x18\x02 \x03(\x0b\x32%.qwak.deployment.management.Variation\x12\x17\n\x0f\x65nvironment_ids\x18\x03 \x03(\t\"\xc6\x02\n\x19\x41pplyModelTrafficResponse\x12\x96\x01\n+environment_to_apply_model_traffic_response\x18\x01 \x03(\x0b\x32\x61.qwak.deployment.management.ApplyModelTrafficResponse.EnvironmentToApplyModelTrafficResponseEntry\x1a\x8f\x01\n+EnvironmentToApplyModelTrafficResponseEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12O\n\x05value\x18\x02 \x01(\x0b\x32@.qwak.deployment.management.EnvironmentApplyModelTrafficResponse:\x02\x38\x01\"*\n\x16GetModelTrafficRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\xea\x02\n\x17GetModelTrafficResponse\x12=\n\nvariations\x18\x01 \x03(\x0b\x32%.qwak.deployment.management.VariationB\x02\x18\x01\x12x\n\x1c\x65nvironment_to_model_traffic\x18\x02 \x03(\x0b\x32R.qwak.deployment.management.GetModelTrafficResponse.EnvironmentToModelTrafficEntry\x12\x1d\n\x11multi_env_support\x18\x03 \x01(\x08\x42\x02\x18\x01\x1aw\n\x1e\x45nvironmentToModelTrafficEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x44\n\x05value\x18\x02 \x01(\x0b\x32\x35.qwak.deployment.management.EnvironmentTrafficMessage:\x02\x38\x01\"-\n\x16IsBuildDeployedRequest\x12\x13\n\x0b\x62uild_uuids\x18\x01 \x03(\t\"a\n\x17IsBuildDeployedResponse\x12\x46\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32\x31.qwak.deployment.management.BuildDeploymentStatus\"*\n\x13IsBuildInUseRequest\x12\x13\n\x0b\x62uild_uuids\x18\x01 \x03(\t\"^\n\x14IsBuildInUseResponse\x12\x46\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32\x31.qwak.deployment.management.BuildDeploymentStatus\"D\n\x18\x43\x61ncelDeploymentsRequest\x12\x16\n\x0e\x64\x65ployment_ids\x18\x01 \x03(\t\x12\x10\n\x08model_id\x18\x02 \x01(\t\"\x81\x02\n\x19\x43\x61ncelDeploymentsResponse\x12m\n\x15\x63\x61ncel_request_status\x18\x01 \x03(\x0b\x32N.qwak.deployment.management.CancelDeploymentsResponse.CancelRequestStatusEntry\x1au\n\x18\x43\x61ncelRequestStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12H\n\x05value\x18\x02 \x01(\x0b\x32\x39.qwak.deployment.management.CancelDeploymentRequestStatus:\x02\x38\x01\"6\n ListLiveModelsDeploymentsRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\"g\n!ListLiveModelsDeploymentsResponse\x12\x42\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32-.qwak.deployment.management.DeploymentDetails2\x87\x0f\n\x1b\x44\x65ploymentManagementService\x12n\n\x0b\x44\x65ployModel\x12..qwak.deployment.management.DeployModelRequest\x1a/.qwak.deployment.management.DeployModelResponse\x12t\n\rUndeployModel\x12\x30.qwak.deployment.management.UndeployModelRequest\x1a\x31.qwak.deployment.management.UndeployModelResponse\x12\x86\x01\n\x13GetDeploymentStatus\x12\x36.qwak.deployment.management.GetDeploymentStatusRequest\x1a\x37.qwak.deployment.management.GetDeploymentStatusResponse\x12\x89\x01\n\x14GetDeploymentDetails\x12\x37.qwak.deployment.management.GetDeploymentDetailsRequest\x1a\x38.qwak.deployment.management.GetDeploymentDetailsResponse\x12\xaa\x01\n\x1fUpdateDeploymentRuntimeSettings\x12\x42.qwak.deployment.management.UpdateDeploymentRuntimeSettingsRequest\x1a\x43.qwak.deployment.management.UpdateDeploymentRuntimeSettingsResponse\x12\x89\x01\n\x14GetDeploymentHistory\x12\x37.qwak.deployment.management.GetDeploymentHistoryRequest\x1a\x38.qwak.deployment.management.GetDeploymentHistoryResponse\x12\xa7\x01\n\x1ePushEnvironmentDeploymentState\x12\x41.qwak.deployment.management.PushEnvironmentDeploymentStateRequest\x1a\x42.qwak.deployment.management.PushEnvironmentDeploymentStateResponse\x12\x85\x01\n\x11\x41pplyModelTraffic\x12\x34.qwak.deployment.management.ApplyModelTrafficRequest\x1a\x35.qwak.deployment.management.ApplyModelTrafficResponse\"\x03\x88\x02\x01\x12\x7f\n\x0fGetModelTraffic\x12\x32.qwak.deployment.management.GetModelTrafficRequest\x1a\x33.qwak.deployment.management.GetModelTrafficResponse\"\x03\x88\x02\x01\x12z\n\x0fIsBuildDeployed\x12\x32.qwak.deployment.management.IsBuildDeployedRequest\x1a\x33.qwak.deployment.management.IsBuildDeployedResponse\x12q\n\x0cIsBuildInUse\x12/.qwak.deployment.management.IsBuildInUseRequest\x1a\x30.qwak.deployment.management.IsBuildInUseResponse\x12t\n\rGetDeployment\x12\x30.qwak.deployment.management.GetDeploymentRequest\x1a\x31.qwak.deployment.management.GetDeploymentResponse\x12\x80\x01\n\x11\x43\x61ncelDeployments\x12\x34.qwak.deployment.management.CancelDeploymentsRequest\x1a\x35.qwak.deployment.management.CancelDeploymentsResponse\x12\x98\x01\n\x19ListLiveModelsDeployments\x12<.qwak.deployment.management.ListLiveModelsDeploymentsRequest\x1a=.qwak.deployment.management.ListLiveModelsDeploymentsResponseBE\n%com.qwak.ai.management.deployment.apiP\x01Z\x1aqwak/deployment;deploymentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.deployment.deployment_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.management.deployment.apiP\001Z\032qwak/deployment;deployment'
  _DEPLOYMODELREQUEST_ENVIRONMENTTODEPLOYMENTENTRY._options = None
  _DEPLOYMODELREQUEST_ENVIRONMENTTODEPLOYMENTENTRY._serialized_options = b'8\001'
  _DEPLOYMODELREQUEST.fields_by_name['branch_id']._options = None
  _DEPLOYMODELREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _DEPLOYMODELREQUEST.fields_by_name['build_id']._options = None
  _DEPLOYMODELREQUEST.fields_by_name['build_id']._serialized_options = b'\030\001'
  _DEPLOYMODELREQUEST.fields_by_name['hosting_service']._options = None
  _DEPLOYMODELREQUEST.fields_by_name['hosting_service']._serialized_options = b'\030\001'
  _DEPLOYMODELRESPONSE_ENVIRONMENTTODEPLOYMENTRESULTENTRY._options = None
  _DEPLOYMODELRESPONSE_ENVIRONMENTTODEPLOYMENTRESULTENTRY._serialized_options = b'8\001'
  _DEPLOYMODELRESPONSE.fields_by_name['deployment_named_id']._options = None
  _DEPLOYMODELRESPONSE.fields_by_name['deployment_named_id']._serialized_options = b'\030\001'
  _DEPLOYMODELRESPONSE.fields_by_name['status']._options = None
  _DEPLOYMODELRESPONSE.fields_by_name['status']._serialized_options = b'\030\001'
  _DEPLOYMODELRESPONSE.fields_by_name['info']._options = None
  _DEPLOYMODELRESPONSE.fields_by_name['info']._serialized_options = b'\030\001'
  _UNDEPLOYMODELREQUEST_ENVIRONMENTTOUNDEPLOYMENTENTRY._options = None
  _UNDEPLOYMODELREQUEST_ENVIRONMENTTOUNDEPLOYMENTENTRY._serialized_options = b'8\001'
  _UNDEPLOYMODELREQUEST.fields_by_name['branch_id']._options = None
  _UNDEPLOYMODELREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _UNDEPLOYMODELREQUEST.fields_by_name['hosting_service_type']._options = None
  _UNDEPLOYMODELREQUEST.fields_by_name['hosting_service_type']._serialized_options = b'\030\001'
  _UNDEPLOYMODELREQUEST.fields_by_name['traffic_config']._options = None
  _UNDEPLOYMODELREQUEST.fields_by_name['traffic_config']._serialized_options = b'\030\001'
  _UNDEPLOYMODELREQUEST.fields_by_name['variation_name']._options = None
  _UNDEPLOYMODELREQUEST.fields_by_name['variation_name']._serialized_options = b'\030\001'
  _UNDEPLOYMODELRESPONSE_ENVIRONMENTTOUNDEPLOYMENTRESULTENTRY._options = None
  _UNDEPLOYMODELRESPONSE_ENVIRONMENTTOUNDEPLOYMENTRESULTENTRY._serialized_options = b'8\001'
  _UNDEPLOYMODELRESPONSE.fields_by_name['status']._options = None
  _UNDEPLOYMODELRESPONSE.fields_by_name['status']._serialized_options = b'\030\001'
  _UNDEPLOYMODELRESPONSE.fields_by_name['info']._options = None
  _UNDEPLOYMODELRESPONSE.fields_by_name['info']._serialized_options = b'\030\001'
  _GETDEPLOYMENTSTATUSREQUEST.fields_by_name['hosting_service_type']._options = None
  _GETDEPLOYMENTSTATUSREQUEST.fields_by_name['hosting_service_type']._serialized_options = b'\030\001'
  _UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST_ENVIRONMENTTORUNTIMEDEPLOYMENTSETTINGSENTRY._options = None
  _UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST_ENVIRONMENTTORUNTIMEDEPLOYMENTSETTINGSENTRY._serialized_options = b'8\001'
  _UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST.fields_by_name['branch_id']._options = None
  _UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST.fields_by_name['deployment_settings']._options = None
  _UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST.fields_by_name['deployment_settings']._serialized_options = b'\030\001'
  _UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST.fields_by_name['variation_name']._options = None
  _UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST.fields_by_name['variation_name']._serialized_options = b'\030\001'
  _UPDATEDEPLOYMENTRUNTIMESETTINGSRESPONSE_ENVIRONMENTTORUNTIMEDEPLOYMENTSETTINGSRESPONSEENTRY._options = None
  _UPDATEDEPLOYMENTRUNTIMESETTINGSRESPONSE_ENVIRONMENTTORUNTIMEDEPLOYMENTSETTINGSRESPONSEENTRY._serialized_options = b'8\001'
  _GETDEPLOYMENTDETAILSREQUEST.fields_by_name['branch_id']._options = None
  _GETDEPLOYMENTDETAILSREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _GETDEPLOYMENTDETAILSRESPONSE_ENVIRONMENTTODEPLOYMENTDETAILSENTRY._options = None
  _GETDEPLOYMENTDETAILSRESPONSE_ENVIRONMENTTODEPLOYMENTDETAILSENTRY._serialized_options = b'8\001'
  _GETDEPLOYMENTDETAILSRESPONSE_BUILDTOENVIRONMENTDEPLOYMENTSTATUSENTRY._options = None
  _GETDEPLOYMENTDETAILSRESPONSE_BUILDTOENVIRONMENTDEPLOYMENTSTATUSENTRY._serialized_options = b'8\001'
  _GETDEPLOYMENTDETAILSRESPONSE.fields_by_name['current_deployment_details']._options = None
  _GETDEPLOYMENTDETAILSRESPONSE.fields_by_name['current_deployment_details']._serialized_options = b'\030\001'
  _GETDEPLOYMENTDETAILSRESPONSE.fields_by_name['last_deployment_brief']._options = None
  _GETDEPLOYMENTDETAILSRESPONSE.fields_by_name['last_deployment_brief']._serialized_options = b'\030\001'
  _GETDEPLOYMENTDETAILSRESPONSE.fields_by_name['current_deployments_details']._options = None
  _GETDEPLOYMENTDETAILSRESPONSE.fields_by_name['current_deployments_details']._serialized_options = b'\030\001'
  _GETDEPLOYMENTDETAILSRESPONSE.fields_by_name['multi_env_support']._options = None
  _GETDEPLOYMENTDETAILSRESPONSE.fields_by_name['multi_env_support']._serialized_options = b'\030\001'
  _GETDEPLOYMENTHISTORYREQUEST.fields_by_name['branch_id']._options = None
  _GETDEPLOYMENTHISTORYREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _GETDEPLOYMENTHISTORYRESPONSE_ENVIRONMENTTODEPLOYMENTHISTORYENTRY._options = None
  _GETDEPLOYMENTHISTORYRESPONSE_ENVIRONMENTTODEPLOYMENTHISTORYENTRY._serialized_options = b'8\001'
  _GETDEPLOYMENTHISTORYRESPONSE.fields_by_name['environment_to_deployment_history']._options = None
  _GETDEPLOYMENTHISTORYRESPONSE.fields_by_name['environment_to_deployment_history']._serialized_options = b'\030\001'
  _APPLYMODELTRAFFICRESPONSE_ENVIRONMENTTOAPPLYMODELTRAFFICRESPONSEENTRY._options = None
  _APPLYMODELTRAFFICRESPONSE_ENVIRONMENTTOAPPLYMODELTRAFFICRESPONSEENTRY._serialized_options = b'8\001'
  _GETMODELTRAFFICRESPONSE_ENVIRONMENTTOMODELTRAFFICENTRY._options = None
  _GETMODELTRAFFICRESPONSE_ENVIRONMENTTOMODELTRAFFICENTRY._serialized_options = b'8\001'
  _GETMODELTRAFFICRESPONSE.fields_by_name['variations']._options = None
  _GETMODELTRAFFICRESPONSE.fields_by_name['variations']._serialized_options = b'\030\001'
  _GETMODELTRAFFICRESPONSE.fields_by_name['multi_env_support']._options = None
  _GETMODELTRAFFICRESPONSE.fields_by_name['multi_env_support']._serialized_options = b'\030\001'
  _CANCELDEPLOYMENTSRESPONSE_CANCELREQUESTSTATUSENTRY._options = None
  _CANCELDEPLOYMENTSRESPONSE_CANCELREQUESTSTATUSENTRY._serialized_options = b'8\001'
  _DEPLOYMENTMANAGEMENTSERVICE.methods_by_name['ApplyModelTraffic']._options = None
  _DEPLOYMENTMANAGEMENTSERVICE.methods_by_name['ApplyModelTraffic']._serialized_options = b'\210\002\001'
  _DEPLOYMENTMANAGEMENTSERVICE.methods_by_name['GetModelTraffic']._options = None
  _DEPLOYMENTMANAGEMENTSERVICE.methods_by_name['GetModelTraffic']._serialized_options = b'\210\002\001'
  _globals['_DEPLOYMODELREQUEST']._serialized_start=148
  _globals['_DEPLOYMODELREQUEST']._serialized_end=538
  _globals['_DEPLOYMODELREQUEST_ENVIRONMENTTODEPLOYMENTENTRY']._serialized_start=418
  _globals['_DEPLOYMODELREQUEST_ENVIRONMENTTODEPLOYMENTENTRY']._serialized_end=538
  _globals['_DEPLOYMODELRESPONSE']._serialized_start=541
  _globals['_DEPLOYMODELRESPONSE']._serialized_end=945
  _globals['_DEPLOYMODELRESPONSE_ENVIRONMENTTODEPLOYMENTRESULTENTRY']._serialized_start=813
  _globals['_DEPLOYMODELRESPONSE_ENVIRONMENTTODEPLOYMENTRESULTENTRY']._serialized_end=945
  _globals['_UNDEPLOYMODELREQUEST']._serialized_start=948
  _globals['_UNDEPLOYMODELREQUEST']._serialized_end=1466
  _globals['_UNDEPLOYMODELREQUEST_ENVIRONMENTTOUNDEPLOYMENTENTRY']._serialized_start=1342
  _globals['_UNDEPLOYMODELREQUEST_ENVIRONMENTTOUNDEPLOYMENTENTRY']._serialized_end=1466
  _globals['_UNDEPLOYMODELRESPONSE']._serialized_start=1469
  _globals['_UNDEPLOYMODELRESPONSE']._serialized_end=1853
  _globals['_UNDEPLOYMODELRESPONSE_ENVIRONMENTTOUNDEPLOYMENTRESULTENTRY']._serialized_start=1717
  _globals['_UNDEPLOYMODELRESPONSE_ENVIRONMENTTOUNDEPLOYMENTRESULTENTRY']._serialized_end=1853
  _globals['_GETDEPLOYMENTREQUEST']._serialized_start=1855
  _globals['_GETDEPLOYMENTREQUEST']._serialized_end=1900
  _globals['_GETDEPLOYMENTRESPONSE']._serialized_start=1903
  _globals['_GETDEPLOYMENTRESPONSE']._serialized_end=2090
  _globals['_GETDEPLOYMENTSTATUSREQUEST']._serialized_start=2093
  _globals['_GETDEPLOYMENTSTATUSREQUEST']._serialized_end=2242
  _globals['_GETDEPLOYMENTSTATUSRESPONSE']._serialized_start=2244
  _globals['_GETDEPLOYMENTSTATUSRESPONSE']._serialized_end=2340
  _globals['_UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST']._serialized_start=2343
  _globals['_UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST']._serialized_end=2878
  _globals['_UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST_ENVIRONMENTTORUNTIMEDEPLOYMENTSETTINGSENTRY']._serialized_start=2728
  _globals['_UPDATEDEPLOYMENTRUNTIMESETTINGSREQUEST_ENVIRONMENTTORUNTIMEDEPLOYMENTSETTINGSENTRY']._serialized_end=2878
  _globals['_UPDATEDEPLOYMENTRUNTIMESETTINGSRESPONSE']._serialized_start=2881
  _globals['_UPDATEDEPLOYMENTRUNTIMESETTINGSRESPONSE']._serialized_end=3272
  _globals['_UPDATEDEPLOYMENTRUNTIMESETTINGSRESPONSE_ENVIRONMENTTORUNTIMEDEPLOYMENTSETTINGSRESPONSEENTRY']._serialized_start=3108
  _globals['_UPDATEDEPLOYMENTRUNTIMESETTINGSRESPONSE_ENVIRONMENTTORUNTIMEDEPLOYMENTSETTINGSRESPONSEENTRY']._serialized_end=3272
  _globals['_GETDEPLOYMENTDETAILSREQUEST']._serialized_start=3274
  _globals['_GETDEPLOYMENTDETAILSREQUEST']._serialized_end=3364
  _globals['_GETDEPLOYMENTDETAILSRESPONSE']._serialized_start=3367
  _globals['_GETDEPLOYMENTDETAILSRESPONSE']._serialized_end=4243
  _globals['_GETDEPLOYMENTDETAILSRESPONSE_ENVIRONMENTTODEPLOYMENTDETAILSENTRY']._serialized_start=3971
  _globals['_GETDEPLOYMENTDETAILSRESPONSE_ENVIRONMENTTODEPLOYMENTDETAILSENTRY']._serialized_end=4105
  _globals['_GETDEPLOYMENTDETAILSRESPONSE_BUILDTOENVIRONMENTDEPLOYMENTSTATUSENTRY']._serialized_start=4108
  _globals['_GETDEPLOYMENTDETAILSRESPONSE_BUILDTOENVIRONMENTDEPLOYMENTSTATUSENTRY']._serialized_end=4243
  _globals['_GETDEPLOYMENTHISTORYREQUEST']._serialized_start=4245
  _globals['_GETDEPLOYMENTHISTORYREQUEST']._serialized_end=4352
  _globals['_GETDEPLOYMENTHISTORYRESPONSE']._serialized_start=4355
  _globals['_GETDEPLOYMENTHISTORYRESPONSE']._serialized_end=4730
  _globals['_GETDEPLOYMENTHISTORYRESPONSE_ENVIRONMENTTODEPLOYMENTHISTORYENTRY']._serialized_start=4596
  _globals['_GETDEPLOYMENTHISTORYRESPONSE_ENVIRONMENTTODEPLOYMENTHISTORYENTRY']._serialized_end=4730
  _globals['_PUSHENVIRONMENTDEPLOYMENTSTATEREQUEST']._serialized_start=4733
  _globals['_PUSHENVIRONMENTDEPLOYMENTSTATEREQUEST']._serialized_end=4882
  _globals['_PUSHENVIRONMENTDEPLOYMENTSTATERESPONSE']._serialized_start=4884
  _globals['_PUSHENVIRONMENTDEPLOYMENTSTATERESPONSE']._serialized_end=4924
  _globals['_APPLYMODELTRAFFICREQUEST']._serialized_start=4927
  _globals['_APPLYMODELTRAFFICREQUEST']._serialized_end=5055
  _globals['_APPLYMODELTRAFFICRESPONSE']._serialized_start=5058
  _globals['_APPLYMODELTRAFFICRESPONSE']._serialized_end=5384
  _globals['_APPLYMODELTRAFFICRESPONSE_ENVIRONMENTTOAPPLYMODELTRAFFICRESPONSEENTRY']._serialized_start=5241
  _globals['_APPLYMODELTRAFFICRESPONSE_ENVIRONMENTTOAPPLYMODELTRAFFICRESPONSEENTRY']._serialized_end=5384
  _globals['_GETMODELTRAFFICREQUEST']._serialized_start=5386
  _globals['_GETMODELTRAFFICREQUEST']._serialized_end=5428
  _globals['_GETMODELTRAFFICRESPONSE']._serialized_start=5431
  _globals['_GETMODELTRAFFICRESPONSE']._serialized_end=5793
  _globals['_GETMODELTRAFFICRESPONSE_ENVIRONMENTTOMODELTRAFFICENTRY']._serialized_start=5674
  _globals['_GETMODELTRAFFICRESPONSE_ENVIRONMENTTOMODELTRAFFICENTRY']._serialized_end=5793
  _globals['_ISBUILDDEPLOYEDREQUEST']._serialized_start=5795
  _globals['_ISBUILDDEPLOYEDREQUEST']._serialized_end=5840
  _globals['_ISBUILDDEPLOYEDRESPONSE']._serialized_start=5842
  _globals['_ISBUILDDEPLOYEDRESPONSE']._serialized_end=5939
  _globals['_ISBUILDINUSEREQUEST']._serialized_start=5941
  _globals['_ISBUILDINUSEREQUEST']._serialized_end=5983
  _globals['_ISBUILDINUSERESPONSE']._serialized_start=5985
  _globals['_ISBUILDINUSERESPONSE']._serialized_end=6079
  _globals['_CANCELDEPLOYMENTSREQUEST']._serialized_start=6081
  _globals['_CANCELDEPLOYMENTSREQUEST']._serialized_end=6149
  _globals['_CANCELDEPLOYMENTSRESPONSE']._serialized_start=6152
  _globals['_CANCELDEPLOYMENTSRESPONSE']._serialized_end=6409
  _globals['_CANCELDEPLOYMENTSRESPONSE_CANCELREQUESTSTATUSENTRY']._serialized_start=6292
  _globals['_CANCELDEPLOYMENTSRESPONSE_CANCELREQUESTSTATUSENTRY']._serialized_end=6409
  _globals['_LISTLIVEMODELSDEPLOYMENTSREQUEST']._serialized_start=6411
  _globals['_LISTLIVEMODELSDEPLOYMENTSREQUEST']._serialized_end=6465
  _globals['_LISTLIVEMODELSDEPLOYMENTSRESPONSE']._serialized_start=6467
  _globals['_LISTLIVEMODELSDEPLOYMENTSRESPONSE']._serialized_end=6570
  _globals['_DEPLOYMENTMANAGEMENTSERVICE']._serialized_start=6573
  _globals['_DEPLOYMENTMANAGEMENTSERVICE']._serialized_end=8500
# @@protoc_insertion_point(module_scope)
